import { useState, useEffect } from "react";
import Taro, { useDidShow } from "@tarojs/taro";
import withLayout from "@/layouts";
import OrderCard from '@/components/CompoentsOrder/OrderCard'
import { getOrderSub } from "@/services/payOrder";
import CustomNav from "@/components/CustomNav";
import "./style.less";


export default withLayout((props) => {
  const { router, person } = props;
  const [list, setList] = useState([]);
  const [IsPull, setPull] = useState(false);
  const [pageNum, setNumber] = useState(1);
  const [HasNextPage, setHasNextPage] = useState(true);
  const [isFirst, setFirst] = useState(true)

  const getList = () => {
    setFirst(false)
    setHasNextPage(false);
    Taro.showLoading()
    getOrderSub({
      pageNum,
      pageSize: 10,
      status: 1,
      isVerified: 0,
    }).then((res) => {
      setList(
        pageNum === 1 ? res.records || [] : list.concat(res.records || [])
      );
      setHasNextPage(res.current < res.pages);
      setPull(false);
      Taro.hideLoading();

    });
  };

  const pageRefresh = () => {
    // 页面下拉刷新回调
    setPull(true);
  };

  const pageLoadMore = () => {
    // 页面上拉加载更多
    if (HasNextPage) {
      setNumber(pageNum + 1);
    }
  };

  useDidShow(() => {
    if (!isFirst) {
      getList();
    }

  })

  useEffect(() => {
    // 下拉刷新触发
    if (IsPull) {
      if (pageNum === 1) {
        getList();
      } else {
        setNumber(1);
      }
    }
  }, [IsPull]);

  useEffect(() => {
    getList();
  }, [pageNum]);
    
  return (
    <view className='box-content'>
      <view className='index-navbar'>
        <CustomNav title='售后退款' />
      </view>
      <scroll-view
        scrollY
        style='height: calc(100vh - 176rpx);'
        refresher-enabled
        refresher-triggered={IsPull}
        onrefresherrefresh={pageRefresh}
        refresher-background='#fff'
        onscrolltolower={pageLoadMore}
      >
        <view className='View-box-Card'>
          {(list || []).map((item) => {
            return (
              <OrderCard item={item}  key={item.orderId} sh='1' />              
            )            
          })}
          <view className='foot'>这是我的底线</view>
        </view>
      </scroll-view>
    </view>
  );
});
